#!/bin/bash

help() {
  /usr/sbin/invoke-rc.d --help
}

# run original command if svctl doesn't exist
if [ -z "$(command -v svctl)" ]; then
  /usr/sbin/invoke-rc.d "$@"
  exit "$?"
fi

# discard option parameters
# if a parameter --query is encountered: exit with status code 105
# if a parameter --help is encountered: display usage information
while [[ $1 =~ ^-- ]]; do
  case "$1" in
    --help)  help; exit 0;;
    --query) exit 105;;
  esac
  shift
done

# need at least 2 non-option arguments (service name and action)
if [ $# -lt 2 ]; then
  help
  exit 1
fi

# only manage service if it's known to s6
if svctl listall | grep -q "^${1}$"; then
  case "$2" in
    start)
      # Using "apply" instead of "start" restores all services to boot
      # configuration. Since dependencies are automatically stopped too when a
      # service is stopped, we want them to be automatically started again when
      # a package uses invoke-rc.d stop/start instead of restart. Services that
      # have been masked (in the boot config) are automatically exempted.
      svctl apply || exit 1
      ;;
    stop|restart)
      svctl "$2" "$1" || exit 1
      ;;
    force-stop)
      svctl stop "$1" || exit 1
      ;;
    try-restart|reload|force-reload)
      svctl restart "$1" || exit 1
      ;;
    status)
      svctl isenabled "$1"
      svctl isup "$1"
      ;;
    *)
      help
      exit 1
      ;;
  esac
else
  echo "Service ${1} is unknown to s6."
fi

exit 0
