#!/bin/bash

help() {
  /usr/sbin/update-rc.d --help
}

# discard all option parameters
while [[ $1 =~ ^- ]]; do
  if [ "$1" = '--help' ] || [ "$1" = '-h' ]; then
    help
    exit 0
  fi
  shift
done

# run original command if svctl doesn't exist
if [ -z "$(command -v svctl)" ]; then
  /usr/sbin/update-rc.d "$@"
  exit "$?"
fi

# need at least 2 non-option arguments (service name and action)
if [ $# -lt 2 ]; then
  help
  exit 1
fi

# update WORKDB, so we can check if service name exists
svctl compile

# only manage service if it's known to s6
if svctl listall | grep -q "^${1}$"; then
  # we're using s6, so always disable the service in Upstart/SysV init
  /usr/sbin/update-rc.d -f "$1" disable

  case "$2" in
    defaults-disabled|disable|remove)
      svctl disable "$1" || exit 1
      ;;
    defaults|enable)
      svctl enable "$1" || exit 1
      ;;
  esac
else
  echo "Service ${1} is unknown to s6."
fi

svctl update

exit 0
